Release An Add-on Release Or A Linked Add-on Release
####################################################

Once you have filled in all required data into the form
of a new add-on release or linked add-on release and saved
the form, you have to decide if and with which state you
want to publish the add-on release.

The release is in the default state at that time. This
means its workflow state is 'Unreleased'. You could
choose another state from the listing in the menubar on
the left side (see screenshot below). Click on the
appropriate entry in this menubar and you get a
listing with the available further workflow state (drop
down menu):

- Release alpha --> Alpha Release
- Release beta  --> Beta Release
- Release candidate
- Final Release.

.. image:: images/addon_release_publish1.png
   :width: 297


If an add-on release or linked add-on release should not
be public available anymore, it could be hidden.
Therefor you choose 'Hide release' from the entries
in the listing in the menu entry (drop down menu).

In case a release got the state 'hidden' the owner
could later decide to 'unhide' it. Therefor she / he
make a mouse click on the entry 'Hidden' in the menubar
on the left side and choose the entry 'Unhide release'.
The (linked) add-on release will get the state
'Unreleased' again and it is possible to publish it
in one of the workflow states again, which are listed
above.

